@@ -16,16 +16,7 @@
 
 class QAbstractItemModel;
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-namespace QtCharts {
 class QChart;
-class QChartView;
-}
-using QtCharts::QChart;
-using QtCharts::QChartView;
-#else
-class QChart;
-#endif
 
 namespace KUserFeedback {
 namespace Console {
