@@ -12,14 +12,7 @@
 #include <memory>
 #include <vector>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-namespace QtCharts {
 class QPieSeries;
-}
-using QtCharts::QPieSeries;
-#else
-class QPieSeries;
-#endif
 
 namespace KUserFeedback {
 namespace Console {
